package WWW::Shorten::Qwer;

use strict;
use warnings;

our $VERSION = '3.094';

require WWW::Shorten::_dead;

0;

=head1 NAME

WWW::Shorten::Qwer - (DEPRECATED) URL Shorten Service

=head1 SYNOPSIS

  # no viable use case

=head1 DESCRIPTION

This module is deprecated since the service no longer functions.  Please
see L<WWW::Shorten> instead.

=head1 AUTHOR

Dave Cross C<dave@perlhacks.com>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

See the main L<WWW::Shorten> docs.

=head1 SEE ALSO

L<WWW::Shorten>

=cut
