package WWW::Shorten::Linkz;

use strict;
use warnings;

our $VERSION = '3.094';

require WWW::Shorten::_dead;

1;

=head1 NAME

WWW::Shorten::Linkz - (DEPRECATED) Shorten URLs

=head1 SYNOPSIS

  # No appropriate use case.

=head1 DESCRIPTION

Unfortunately, this service became inactive.  So, this module will merely give
you an error if you try to use it. Feel free to pick a different
L<service|WWW::Shorten>.

=head1 AUTHOR

Iain Truskett <spoon@cpan.org>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=item *

Dave Cross C<dave@perlhacks.com>

=back

=head1 SEE ALSO

L<WWW::Shorten>

=cut
