package WWW::Shorten::Tinylink;

use strict;
use warnings;

our $VERSION = '3.094';

require WWW::Shorten::_dead;

1;

=head1 NAME

WWW::Shorten::Tinylink - (DEPRECATED) Shorten URLs

=head1 SYNOPSIS

  # No appropriate solution

=head1 DESCRIPTION

Unfortunately, at some point in the middle of 2008, this service stopped
returning usable URLs and therefore this module is now deprecated

=head1 AUTHOR

Iain Truskett C<spoon@cpan.org>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=item *

Dave Cross C<dave@perlhacks.com>

=back

=head1 COPYRIGHT AND LICENSE

Under the terms and copyright of L<WWW::Shorten>

=head1 SEE ALSO

L<WWW::Shorten>

=cut
