package WWW::Shorten::Metamark;

use strict;
use warnings;

our $VERSION = '3.094';

require WWW::Shorten::_dead;

1;

=head1 NAME

WWW::Shorten::Metamark - (DEPRECATED) Shorten URLs

=head1 SYNOPSIS

  # No appropriate use case

=head1 DESCRIPTION

Unfortunately, this service became inactive at some point between 1.89
and 1.90, so this module will merely give you an error if you try to use
it. Feel free to pick a different L<service|WWW::Shorten>.

=head1 AUTHOR

Iain Truskett C<spoon@cpan.org>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=item *

Dave Cross C<dave@perlhacks.com>

=back

=head1 COPYRIGHT AND LICENSE

Under the terms and copyright of L<WWW::Shorten>

=head1 SEE ALSO

L<WWW::Shorten>

=cut
